@@ -10,7 +10,7 @@ def profitsharing_order(self, transaction_id, out_order_no, receivers, unfreeze_
     :param out_order_no: 商户分账单号，只能是数字、大小写字母_-|*@，示例值：'P20150806125346'
     :param receivers: 分账接收方列表，最多可有50个分账接收方，示例值：{{'type':'MERCHANT_ID', 'account':'86693852', 'amount':888, 'description':'分给商户A'}}
     :param unfreeze_unsplit: 是否解冻剩余未分资金，示例值：True, False
-    :param appid: 应用ID，可不填，默认传入初始化时的appid，示例值：'wx1234567890abcdef'    
+    :param appid: 应用ID，可不填，默认传入初始化时的appid，示例值：'wx1234567890abcdef'
     :param sub_appid: (服务商模式)子商户应用ID，示例值：'wxd678efh567hg6999'
     :param sub_mchid: (服务商模式)子商户的商户号，由微信支付生成并下发。示例值：'1900000109'
     """
@@ -23,7 +23,7 @@ def profitsharing_order(self, transaction_id, out_order_no, receivers, unfreeze_
         params.update({'out_order_no': out_order_no})
     else:
         raise Exception('out_order_no is not assigned')
-    if unfreeze_unsplit:
+    if isinstance(unfreeze_unsplit, bool):
         params.update({'unfreeze_unsplit': unfreeze_unsplit})
     else:
         raise Exception('unfreeze_unsplit is not assigned')
@@ -31,7 +31,9 @@ def profitsharing_order(self, transaction_id, out_order_no, receivers, unfreeze_
         params.update({'receivers': receivers})
     else:
         raise Exception('receivers is not assigned')
-    params.update({'appid': appid if appid else self._core._appid})
+    if params.get('receivers').get('name'):
+        params['receivers']['name'] = self._core.encrypt(params['receivers']['name'])
+    params.update({'appid': appid if appid else self._appid})
     if self._partner_mode:
         if sub_appid:
             params.update({'sub_appid': sub_appid})
@@ -273,7 +275,7 @@ def brand_profitsharing_order(self, brand_mchid, sub_mchid, transaction_id, out_
     :param out_order_no: 商户分账单号，只能是数字、大小写字母_-|*@，示例值：'P20150806125346'
     :param receivers: 分账接收方列表，最多可有50个分账接收方，示例值：{{'type':'MERCHANT_ID', 'account':'86693852', 'amount':888, 'description':'分给商户A'}}
     :param finish: 是否完成分账，示例值：True, False
-    :param appid: 应用ID，可不填，默认传入初始化时的appid，示例值：'wx1234567890abcdef'    
+    :param appid: 应用ID，可不填，默认传入初始化时的appid，示例值：'wx1234567890abcdef'
     :param sub_appid: 子商户应用ID，示例值：'wxd678efh567hg6999'
     """
     params = {}
